@@ -7,15 +7,16 @@
 checkCoords <- function(data, coords) {
   
   coords_in <- sapply(data, function(dat) {
-    if (inherits(dat,'data.frame')) 
-      coords %in% names(dat)
+    if (inherits(dat,'data.frame'))
+      if (!inherits(dat, 'sf')) coords %in% names(dat)
+      else TRUE
     else if (inherits(dat, "Spatial")) {
       x_coord <- colnames(dat@coords)[1]
       y_coord <- colnames(dat@coords)[2]
       coords %in% c(x_coord, y_coord)
     }
   })
-  if (!all(coords_in)) OK <- FALSE
+  if (!all(unlist(coords_in))) OK <- FALSE
   else OK <- TRUE
   
   OK
