@@ -54,7 +54,7 @@ test_that('datasetOut is able to correctly remove the correct datasets and metad
   names(cov) <- 'covariate'
   
   obj <- intModel(PO, PA, Coordinates = coordnames, Projection = projection, Mesh = mesh,
-                 IPS = iPoints, trialsPA = trialName, responseCounts = responseCounts, 
+                 IPS = iPoints, trialsPA = trialName, responseCounts = responseCounts, speciesSpatial = 'individual',
                  responsePA = responsePA, markNames = c('factvar'), markFamily = c('multinomial'),
                  speciesName = speciesName, spatialCovariates = cov, pointsSpatial = NULL)
   
